@@ -12,11 +12,11 @@ use in XML::Grammar::Fiction::FromProto.
 
 =head1 VERSION
 
-Version 0.7.0
+Version 0.8.0
 
 =cut
 
-our $VERSION = '0.7.0';
+our $VERSION = '0.8.0';
 
 package XML::Grammar::Fiction::FromProto::Node;
 
@@ -93,6 +93,13 @@ use Moose;
 
 extends("XML::Grammar::Fiction::FromProto::Node::WithContent");
 
+sub get_text
+{
+    my ($self, $re) = @_;
+
+    return $self->children->contents->[0];
+}
+
 package XML::Grammar::Fiction::FromProto::Node::Saying;
 
 use Moose;
